<?php

  /*  Copyright 2013 cooksnaps.com  (email : tech@cooksnaps.com)

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2, as
  published by the Free Software Foundation.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */

  /*
  Plugin Name: Cooksnaps
  Plugin URI: http://www.cooksnaps.com
  Description: Cooksnaps is a system to help recipe bloggers to receive photos when other people cook their recipes. Head over to the Cooksnaps admin page to get set up.
  Author: Cooksnaps
  Version: 1.0
  Author URI: http://www.cooksnaps.com
  License: GPLv2 or later
  Text Domain: cooksnaps
  */

  define("COOKSNAPS_META_ID", "cksnp_widg_show");
  define("COOKSNAPS_LANGUAGES", serialize(array("en" => "English", "es" => "Español", "it" => "Italiano", "ja" => "日本語")));
  define("COOKSNAPS_OPTION_LOCALE", "cooksnaps_locale");
  define("COOKSNAPS_OPTION_KEY", "cooksnaps_key");


  function cooksnaps_add($content){
    global $post;
    if(!is_page()) {
      $cooksnaps_script = "<a class=\"cooksnaps_widget\" href=\"" . get_permalink($post->ID) . "\">Cooksnaps</a>";
      if (strpos($content, 'more-link') === false) {
        $meta_value = get_post_meta($post->ID, COOKSNAPS_META_ID, true);
        if ($meta_value == '1') {
            return $content . $cooksnaps_script;
        } else {
            return $content;
        }
      }
    }
    return $content;
  }

  function cooksnaps_add_js(){
    if(!is_page()) {
      echo "
            <script type=\"text/javascript\">
              var cs_widget_author_key = '" . get_option(COOKSNAPS_OPTION_KEY) . "';
              var cs_widget_locale = '" . get_option(COOKSNAPS_OPTION_LOCALE) . "';

              (function() {
                var cs = document.createElement('script'); cs.async = true; cs.type = 'text/javascript';
                cs.src = 'http://cooksnaps.com/v1/widget.js?callback=?';
                (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(cs);
              })();
            </script>
      ";
    }
  }

  //Dashboard functions
  //add post sidebar option selector
  function cooksnaps_dash_post_sidebar(){
    global $post;
    $post_type = get_post_type($post);
    $post_type_object = get_post_type_object($post_type);

    add_meta_box('customsidebars-cooksnaps', 'Cooksnaps', 'printMetabox', $post_type, 'side');
  }

  function printMetabox(){
    global $post;
    $meta_value = get_post_meta($post->ID, COOKSNAPS_META_ID, true);
    if ($meta_value == '') {
      $meta_value = "1";
      update_post_meta($post->ID, COOKSNAPS_META_ID, "1");
    }
    $cooksnap_checked = $meta_value == "1" ? true : false;
    include('cooksnapbox.php');
  }

  function cooksnaps_post_save($post_id){
    $cooksnap_widget_select = "0";
    $post = get_post($post_id);
    if (isset($_REQUEST['cooksnapwidget']) || $post->post_status == 'auto-draft') $cooksnap_widget_select = "1";
    update_post_meta($post_id, COOKSNAPS_META_ID, $cooksnap_widget_select);
  }

  /* Post list functions */
  function cooksnaps_custom_columns($column, $post_id) {
    echo '<input type="checkbox" disabled', (cooksnaps_is_available($post_id) ? ' checked' : ''), '/>';
  }

  function cooksnaps_is_available($post_id) {
    $meta_value = get_post_meta($post_id, COOKSNAPS_META_ID, true);
    if ($meta_value == '1') return true;
    return false;
  }

  /* Add custom column to post list */
  function cooksnaps_add_sticky_column($columns) {
    return array_merge($columns,
        array('cooksnap' => '<div id="CS" title="Cooksnaps?"></div>'));
  }
  function cooksnaps_admin_style(){
    wp_enqueue_style('cooksnaps_admin_css', plugins_url('admin/cooksnaps-post-column.php', __FILE__) , false, '1.0', 'all');
  }

  /* Add admin menu */
  function cooksnaps_custom_menu_page(){
    if (current_user_can('manage_options')) {
      add_menu_page('Cooksnaps options',
                     'Cooksnaps',
                     'manage_options',
                     'cooksnaps_options',
                     'cooksnaps_options_page',
                     plugins_url('img/cooksnaps-16.png', __FILE__), 26.1);
    }
  }

  function cooksnaps_options_page(){
    include('admin/cooksnaps_settings.php');
  }

  function cooksnaps_process_locale_option(){
    if (!current_user_can('manage_options')) {
      wp_die('You are not allowed to be on this page.');
    }

    // Check that nonce field
   check_admin_referer('cksnps_op_verify');

   if (isset($_POST['cooksnaps_locale'])) {
      update_option(COOKSNAPS_OPTION_LOCALE, sanitize_text_field($_POST['cooksnaps_locale']));
   }
   wp_redirect(admin_url('admin.php?page=cooksnaps_options'));
   exit;
  }

  function cooksnaps_process_key_option(){
    if (!current_user_can('manage_options')) {
      wp_die('You are not allowed to be on this page.');
    }

    // Check that nonce field
   check_admin_referer('cksnps_ky_verify');

   if (isset($_POST['cooksnaps_key'])) {
      update_option(COOKSNAPS_OPTION_KEY, sanitize_text_field($_POST['cooksnaps_key']));
   }
   wp_redirect(admin_url('admin.php?page=cooksnaps_options'));
   exit;
  }

  function cooksnaps_addall_option() {
    if (!current_user_can('manage_options')) {
      wp_die('You are not allowed to be on this page.');
    }

    // Check that nonce field
    check_admin_referer('cksnps_aa_verify');

    $args = array(
        'numberposts'       => -1,
        'post_type'         => 'post',
        'suppress_filters'  => true
    );
    $posts = get_posts($args);
    foreach ($posts as $post) {
      update_post_meta($post->ID, COOKSNAPS_META_ID, "1"); //updates all published posts
    }

    wp_redirect(admin_url('edit.php'));
    exit;
  }

  //activation / deactivation
  function cooksnaps_activate() {
    if (get_option(COOKSNAPS_OPTION_LOCALE) == '') {
      add_option(COOKSNAPS_OPTION_LOCALE, 'en', '', 'yes');
    }
    if (get_option(COOKSNAPS_OPTION_KEY) == '') {
      add_option(COOKSNAPS_OPTION_KEY, '', '', 'yes');
    }
  }

  function cooksnaps_deactivate() {
    delete_post_meta_by_key(COOKSNAPS_META_ID);
    delete_option(COOKSNAPS_OPTION_LOCALE);
    delete_option(COOKSNAPS_OPTION_KEY);

    // Clear the permalinks to remove our post type's rules
    flush_rewrite_rules();
  }

  add_action('the_content', 'cooksnaps_add');
  add_action('wp_head', 'cooksnaps_add_js');

  /* Add box to post sidebar and save hook */
  add_action('add_meta_boxes', 'cooksnaps_dash_post_sidebar');
  add_action('save_post', 'cooksnaps_post_save');

  /* Add custom column to post list */
  add_action('manage_posts_custom_column' , 'cooksnaps_custom_columns', 10, 2);
  add_filter('manage_posts_columns' , 'cooksnaps_add_sticky_column');
  add_action('admin_init', 'cooksnaps_admin_style');

  /* Add admin menu */
  add_action('admin_menu', 'cooksnaps_custom_menu_page');
  add_action('admin_post_cksnp_save_locale_option', 'cooksnaps_process_locale_option');
  add_action('admin_post_cksnp_addall_option', 'cooksnaps_addall_option');
  add_action('admin_post_cksnp_save_key_option', 'cooksnaps_process_key_option');

  /*Internationalization*/
  load_plugin_textdomain('cooksnaps', false, basename(dirname(__FILE__)) . '/locales');

  //activation / deactivation
  register_activation_hook(__FILE__, 'cooksnaps_activate');
  register_deactivation_hook(__FILE__, 'cooksnaps_deactivate');

  /*End of File*/
